@@ -376,8 +376,11 @@ transContrToT = function(fact, contr){
         effFactors[[1]] = vector("list", nEffect)
         names(effFactors[[1]]) = names(T)
         for(i in 1:nEffect){
+          #eigenvalues of the information matrix
           va = Re(eigen(T[[i]] %*% t(N) %*% PNTginvATNP[[1]] %*% N %*% T[[i]])$va)
-          effFactors[[1]][[i]] = mean(va[which(va>1e-6)]/Rep[names(T[i])])
+          #harmonic means of the canonical efficiency factors to give the average efficiency factor
+          effFactors[[1]][[i]] = 1/mean(Rep[names(T[i])]/va[which(va>1e-6)])           
+          
         } 
       }
       
@@ -391,8 +394,9 @@ transContrToT = function(fact, contr){
           effFactors[[i]] = vector("list", nEffect)
            names(effFactors[[i]]) = names(T)
           for(j in 1:nEffect){
-             va = Re(eigen(T[[j]] %*% t(N) %*% PNTginvATNP[[i]] %*% N %*% T[[j]])$va)
-            effFactors[[i]][[j]] =mean(va[which(va>1e-6)]/Rep[names(T[j])])
+            va = Re(eigen(T[[j]] %*% t(N) %*% PNTginvATNP[[i]] %*% N %*% T[[j]])$va)
+            effFactors[[i]][[j]] = 1/mean(Rep[names(T[j])]/va[which(va>1e-6)])
+            
           }
           newZ = (newZ %*% t(newZ)) - PNTginvATNP[[i]]
         }
